@@ -1,5 +1,7 @@
 """
-Main interface for appflow service literal definitions.
+Type annotations for appflow service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/literals.html)
 
 Usage::
 
